RuntimeCondition

Enum RuntimeCondition 

pub enum RuntimeCondition<'a> {
    DynamicCompileTimeInput {
        operator: OperatorId,
        input_index: u16,
        value: ValueId,
        required_error_check: bool,
    },
    ShiftInRange {
        operator: OperatorId,
        value: ValueId,
        maximum: u8,
    },
    NonZero {
        operator: OperatorId,
        value: ValueId,
    },
    Int32MultiplyInRange {
        operator: OperatorId,
        left: ValueId,
        right: ValueId,
        shift: ValueId,
    },
    PowDomain {
        operator: OperatorId,
        base: ValueId,
        exponent: ValueId,
    },
    IndicesInRange {
        operator: OperatorId,
        indices: ValueId,
        upper_bound: u64,
    },
    ScatterIndicesUnique {
        operator: OperatorId,
        indices: ValueId,
    },
    VariableState {
        operator: OperatorId,
        value: ValueId,
    },
    Custom {
        operator: OperatorId,
        domain: &'a str,
        name: &'a str,
    },
}
Conditions that a provider may need to lower or inspect at execution time.

REQUIRE failures make a TOSA graph unpredictable and need not be detected. Dynamic CTC inputs can affect mandatory ERROR_IF checks and therefore are classified separately.

Variants



DynamicCompileTimeInput

Fields

operator: OperatorId
input_index: u16
value: ValueId
required_error_check: bool


ShiftInRange

Fields

operator: OperatorId
value: ValueId
maximum: u8


NonZero

Fields

operator: OperatorId
value: ValueId


Int32MultiplyInRange

Fields

operator: OperatorId
left: ValueId
right: ValueId
shift: ValueId


PowDomain

Fields

operator: OperatorId
base: ValueId
exponent: ValueId


IndicesInRange

Fields

operator: OperatorId
indices: ValueId
upper_bound: u64


ScatterIndicesUnique

Fields

operator: OperatorId
indices: ValueId


VariableState

Fields

operator: OperatorId
value: ValueId


Custom

Fields

operator: OperatorId
domain: &'a str
name: &'a str

Implementations

Source

impl RuntimeCondition<'_>

pub const fn error_detection_required(self) -> bool

Whether a failing condition must be surfaced as a TOSA error for predictable inputs.