pub struct DType(/* private fields */);Expand description
A TOSA tensor data-type discriminant.
Raw values remain representable so policy and diagnostic utilities can discuss newer schemas.
Successfully parsed models contain only values accepted by DType::is_tosa_1_0.
Implementations
Sourceimpl DType
impl DType
pub const BOOL: Self
pub const INT4: Self
pub const INT8: Self
pub const INT16: Self
pub const INT32: Self
pub const INT48: Self
pub const FP32: Self
pub const FP16: Self
pub const BF16: Self
pub const SHAPE: Self
pub const FP8E4M3: Self
pub const FP8E5M2: Self
pub const fn new(raw: u32) -> Self
pub const fn get(self) -> u32
pub const fn is_tosa_1_0(self) -> bool
pub fn name(self) -> Option<&'static str>