pub struct DTypeConstraints(/* private fields */);Implementations
Sourceimpl DTypeConstraints
impl DTypeConstraints
Sourcepub const PARAMETER_ONLY: Self
pub const PARAMETER_ONLY: Self
This dtype is accepted only when a constant is consumed as a compile-time operator parameter and does not become a graph-visible provider tensor.