pub struct Shape<'a>(/* private fields */);Expand description
Borrowed shape-value view.
Implementations
Sourceimpl<'a> Shape<'a>
impl<'a> Shape<'a>
pub fn name(&self) -> &'a str
pub fn rank(&self) -> u32
pub fn data(&self) -> &'a [u8]
Sourcepub fn values(&self) -> Option<ShapeValues<'a>>
pub fn values(&self) -> Option<ShapeValues<'a>>
Decoded shape values, or None for a nonempty intermediate shape without constant data.
A rank-zero shape is the constant empty list and therefore returns an empty iterator.