pub struct SpecializationCache<V> { /* private fields */ }Expand description
Small exact-key LRU for compiled shape specializations.
This portable cache is deliberately synchronization-free. A concurrent provider should put a lock or single-flight compilation state around it at its existing program/queue owner boundary.
Implementations
Sourceimpl<V> SpecializationCache<V>
impl<V> SpecializationCache<V>
pub fn new(capacity: NonZeroUsize) -> Self
pub const fn capacity(&self) -> usize
pub fn len(&self) -> usize
pub fn is_empty(&self) -> bool
pub fn get(&mut self, key: &SpecializationKey) -> Option<&V>
pub fn get_mut(&mut self, key: &SpecializationKey) -> Option<&mut V>
Sourcepub fn insert(
&mut self,
key: SpecializationKey,
value: V,
) -> Result<Option<V>, CacheInsertError<V>>
pub fn insert( &mut self, key: SpecializationKey, value: V, ) -> Result<Option<V>, CacheInsertError<V>>
Insert or replace a specialization, returning the replaced or evicted compiled value.