pub enum RuntimeCondition<'a> {
DynamicCompileTimeInput {
operator: OperatorId,
input_index: u16,
value: ValueId,
required_error_check: bool,
},
ShiftInRange {
operator: OperatorId,
value: ValueId,
maximum: u8,
},
NonZero {
operator: OperatorId,
value: ValueId,
},
Int32MultiplyInRange {
operator: OperatorId,
left: ValueId,
right: ValueId,
shift: ValueId,
},
PowDomain {
operator: OperatorId,
base: ValueId,
exponent: ValueId,
},
IndicesInRange {
operator: OperatorId,
indices: ValueId,
upper_bound: u64,
},
ScatterIndicesUnique {
operator: OperatorId,
indices: ValueId,
},
VariableState {
operator: OperatorId,
value: ValueId,
},
Custom {
operator: OperatorId,
domain: &'a str,
name: &'a str,
},
}Expand description
Conditions that a provider may need to lower or inspect at execution time.
REQUIRE failures make a TOSA graph unpredictable and need not be detected. Dynamic CTC
inputs can affect mandatory ERROR_IF checks and therefore are classified separately.
Variants
DynamicCompileTimeInput
ShiftInRange
NonZero
Int32MultiplyInRange
PowDomain
IndicesInRange
ScatterIndicesUnique
VariableState
Custom
Implementations
Sourceimpl RuntimeCondition<'_>
impl RuntimeCondition<'_>
Sourcepub const fn error_detection_required(self) -> bool
pub const fn error_detection_required(self) -> bool
Whether a failing condition must be surfaced as a TOSA error for predictable inputs.